# random_poem
A python package that returns a random poem from [poetryfoundation.org](poetryfoundation.org)

## installation
This package can be installed using pip 
`pip install random_poem`

## usage

    import random_poem
    random_poem.get_poem()
    
The call will return a random poem as a `\n` delimited string or `None` if it is not able to find one

## license

random_poem is distributed under the MIT license 